@@ -40,7 +40,7 @@ def load_dataset(
     name: str = "mnist",
     normalize: bool = True,
     augment: bool = False,
-    data_folder: str = "~/torch_datasets",
+    data_folder: str = "~/datasets",
     vectorizer: str = "tfidf",
     return_vectorizer: bool = False,
     image_size: int = 64,
@@ -123,10 +123,10 @@ def load_dataset(
     if augment and name in ["mnist", "fashion_mnist", "emnist", "kmnist"]:
         train_transform = torchvision.transforms.Compose(
             [
+                torchvision.transforms.ToTensor(),
                 torchvision.transforms.RandomHorizontalFlip(),
                 torchvision.transforms.RandomVerticalFlip(),
                 torchvision.transforms.Normalize((0.1307,), (0.3081,)),
-                torchvision.transforms.ToTensor(),
             ]
         )
     elif (
@@ -134,7 +134,7 @@ def load_dataset(
         and normalize
         and name in ["mnist", "fashion_mnist", "emnist", "kmnist"]
     ):
-        train_transform = torchvision.transform.Compose(
+        train_transform = torchvision.transforms.Compose(
             [
                 torchvision.transforms.ToTensor(),
                 torchvision.transforms.Normalize((0.1307,), (0.3081,)),
@@ -188,10 +188,10 @@ def load_dataset(
         )
     elif name == "svhn":
         train_dataset = torchvision.datasets.SVHN(
-            root=data_folder, split="train", download=True, transform=transform
+            root=data_folder, split="train", download=True, transform=train_transform
         )
         test_dataset = torchvision.datasets.SVHN(
-            root=data_folder, split="test", download=True, transform=transform
+            root=data_folder, split="test", download=True, transform=test_transform
         )
     elif name == "malimg":
         train_dataset, test_dataset = load_malimg()
@@ -213,23 +213,23 @@ def load_dataset(
             )
     elif name == "kmnist":
         train_dataset = torchvision.datasets.KMNIST(
-            root=data_folder, train=True, download=True, transform=transform
+            root=data_folder, train=True, download=True, transform=train_transform
         )
         test_dataset = torchvision.datasets.KMNIST(
-            root=data_folder, train=False, download=True, transform=transform
+            root=data_folder, train=False, download=True, transform=test_transform
         )
     elif name == "wdbc":
         train_dataset, test_dataset = load_wdbc()
     elif name == "binary_covid":
         train_dataset, test_dataset = load_binary_covid19(
-            transform=transform,
+            transform=None,
             size=image_size,
             preprocessed=preprocessed_covidx,
             preprocessing_bsize=preprocessing_bsize,
         )
     elif name == "multi_covid":
         train_dataset, test_dataset = load_multi_covid19(
-            transform=transform,
+            transform=None,
             size=image_size,
             preprocessed=preprocessed_covidx,
             preprocessing_bsize=preprocessing_bsize,
@@ -310,7 +310,7 @@ def load_agnews(
         The text vectorizer object.
     """
     path = str(Path.home())
-    path = os.path.join(path, "torch_datasets")
+    path = os.path.join(path, "datasets")
     train_path = os.path.join(path, "ag_news.train")
     test_path = os.path.join(path, "ag_news.test")
     train_dataset, test_dataset = (read_data(train_path), read_data(test_path))
