@@ -22,11 +22,15 @@ from typing import Dict, List, Tuple
 from zipfile import ZipFile
 
 import cv2
+from imblearn.over_sampling import SMOTE
 import nltk
 import numpy as np
 from sklearn.feature_extraction.text import CountVectorizer, TfidfVectorizer
 import torch
 
+from . import create_dataset
+
+
 __author__ = "Abien Fred Agarap"
 
 
@@ -272,3 +276,36 @@ def load_image(filename: str, size: Tuple = 224) -> torch.Tensor:
     image = central_crop(image)
     image = cv2.resize(image, (size, size))
     return image
+
+
+def oversample_dataset(
+    features: torch.Tensor, labels: torch.Tensor, seed: int = 42
+) -> torch.utils.data.Dataset:
+    """
+    Oversamples the minority class in the given dataset
+    using synthetic minority oversampling technique.
+
+    Parameters
+    ----------
+    features: torch.Tensor
+        The dataset features.
+    labels: torch.Tensor
+        The dataset labels.
+    seed: int
+        The random seed to use for sampling.
+
+    Returns
+    -------
+    dataset: torch.utils.data.Dataset
+        The dataset that consists of the
+        oversampled minority class with other classes.
+    """
+    oversampler = SMOTE(random_state=seed, n_jobs=-1)
+    if len(features.shape) > 3:
+        input_shape = features.shape
+    if len(features.shape) > 2:
+        features = features.reshape(features.shape[0], -1)
+    features, labels = oversampler.fit_resample(features, labels)
+    features = np.reshape(features, (features.shape[0], *input_shape[1:]))
+    dataset = create_dataset(features=features, labels=labels)
+    return dataset
